@@ -4,6 +4,7 @@
 
     Copyright (C) 1997 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
     Copyright (C) 2004, 2005 Nicolas GOUTTE <goutte@kde.org>
+    Copyright (C) 2015, 2016 Wolfgang Bauer <wbauer@tmo.at>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,21 +38,22 @@
 #include <QKeyEvent>
 #include <QCloseEvent>
 #include <QtDBus/QtDBus>
-#include <kconfig.h>
+#include <KConfig>
 
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <khelpmenu.h>
-#include <kpushbutton.h>
+#include <QPushButton>
 #include <kmenu.h>
 #include <kapplication.h>
 #include <qprogressbar.h>
 #include <klocale.h>
 #include <kcombobox.h>
 #include <klineedit.h>
-#include <kurl.h>
-#include <ktoolinvocation.h>
-#include <kglobal.h>
+#include <QUrl>
+#include <khelpclient.h>
+#include <KGuiItem>
+#include <KStandardGuiItem>
 
 FloppyData::FloppyData(QWidget * parent)
  : KDialog( parent ),
@@ -283,7 +285,7 @@ FloppyData::FloppyData(QWidget * parent)
 	QVBoxLayout* v3 = new QVBoxLayout();
         h1->addItem( v3 );
 
-	formatbutton = new KPushButton( widget );
+	formatbutton = new QPushButton( widget );
 	formatbutton->setText(i18n( "&Format") );
 	formatbutton->setAutoRepeat( false );
         if (!numFileSystems)
@@ -296,14 +298,16 @@ FloppyData::FloppyData(QWidget * parent)
         v3->addStretch( 1 );
 
 	//Setup the Help Menu
-	helpMenu = new KHelpMenu(this, KGlobal::mainComponent().aboutData(), false);
+	helpMenu = new KHelpMenu(this, KAboutData::applicationData(), false);
 
-	helpbutton = new KPushButton( KStandardGuiItem::help(), widget );
+	helpbutton = new QPushButton( widget );
+	KGuiItem::assign( helpbutton, KStandardGuiItem::help() );
 	helpbutton->setAutoRepeat( false );
 	helpbutton->setMenu(helpMenu->menu());
 	v3->addWidget( helpbutton );
 
-	quitbutton = new KPushButton( KStandardGuiItem::quit(), widget );
+	quitbutton = new QPushButton( widget );
+	KGuiItem::assign( quitbutton, KStandardGuiItem::quit() );
 	quitbutton->setAutoRepeat( false );
 	connect(quitbutton,SIGNAL(clicked()),this,SLOT(quit()));
 	 v3->addWidget( quitbutton );
@@ -360,7 +364,7 @@ void FloppyData::keyPressEvent(QKeyEvent *e)
 {
 	switch(e->key()) {
 	case Qt::Key_F1:
-		KToolInvocation::invokeHelp();
+		KHelpClient::invokeHelp();
 		break;
 	default:
 		KDialog::keyPressEvent(e);
@@ -418,8 +422,8 @@ bool FloppyData::setInitialDevice(const QString& dev)
 
   QString newDevice = dev;
 
-  KUrl url( newDevice );
-  if( url.isValid() && ( url.protocol() == QLatin1String( "media" ) || url.protocol() == QLatin1String( "system" ) ) ) {
+  QUrl url( newDevice );
+  if( url.isValid() && ( url.scheme() == QLatin1String( "media" ) || url.scheme() == QLatin1String( "system" ) ) ) {
     QString name = url.fileName();
 
     QDBusInterface mediamanager( QLatin1String( "org.kde.kded" ), QLatin1String( "/modules/mediamanager" ), QLatin1String( "org.kde.MediaManager" ) );
@@ -687,7 +691,7 @@ void FloppyData::formatStatus(const QString &s,int p)
 
 void FloppyData::writeSettings(){
 
-        KConfigGroup config = KGlobal::config()->group("GeneralData");
+        KConfigGroup config = KSharedConfig::openConfig()->group("GeneralData");
 
 	densityconfig = densityComboBox->currentText().trimmed();
 	filesystemconfig = filesystemComboBox->currentText().trimmed();
@@ -715,7 +719,7 @@ void FloppyData::writeSettings(){
 
 void FloppyData::readSettings(){
 
-        KConfigGroup config = KGlobal::config()->group("GeneralData");
+        KConfigGroup config = KSharedConfig::openConfig()->group("GeneralData");
 
 	verifyconfig = config.readEntry("Verify", 1);
 	labelconfig = config.readEntry("CreateLabel",1);
